Learn R Programming

tndata (version 0.1.0)

get_authors: List All Authors in the Dataset Catalog

Description

Retrieves a list of all authors who have contributed datasets to the catalog by fetching datasets and extracting unique author information.

Usage

get_authors(max_datasets = 1000)

Value

A tibble (data frame) with the following columns:

name

Character. Name of the author.

count

Numeric. Number of datasets contributed by this author.

Arguments

max_datasets

Numeric. Maximum number of datasets to retrieve for author extraction, defaults to 1000.

Examples

Run this code
try({
  authors <- get_authors(max_datasets = 100)
  head(authors)
})

Run the code above in your browser using DataLab