powered by
Retrieves a list of all authors who have contributed datasets to the catalog by fetching datasets and extracting unique author information.
get_authors(max_datasets = 1000)
A tibble (data frame) with the following columns:
Character. Name of the author.
Numeric. Number of datasets contributed by this author.
Numeric. Maximum number of datasets to retrieve for author extraction, defaults to 1000.
try({ authors <- get_authors(max_datasets = 100) head(authors) })
Run the code above in your browser using DataLab