Learn R Programming

tndata (version 0.1.0)

get_organizations: List Organizations

Description

Retrieves organizations data from the Tunisian data catalog API (data.gov.tn) using faceted search. This function returns organizations that have published datasets.

Usage

get_organizations(min_count = 1)

Value

A tibble (data frame) with the following columns:

name

Character. Machine-readable name/identifier of the organization.

display_name

Character. Human-readable name of the organization.

dataset_count

Integer. Number of datasets published by the organization.

Arguments

min_count

Integer. Minimum number of datasets an organization must have to be included in results. Default is 1, meaning only organizations with at least one dataset are returned.

Examples

Run this code
try({
  # Get all organizations with at least 5 datasets
  orgs <- get_organizations(min_count = 5)
  head(orgs)
})

Run the code above in your browser using DataLab